feedgen.ext.podcast_entry — python-feedgen 0.2.8 documentation

# python-feedgen 0.2.8 documentation

## feedgen.ext.podcast_entry

Contents

# feedgen.ext.podcast_entry

Extends the feedgen to produce podcasts.

copyright: | 2013, Lars Kiesow <lkiesow@uos.de>
license: | FreeBSD and LGPL, see license.* for more details.

class `feedgen.ext.podcast_entry.` `PodcastEntryExtension`

  FeedEntry extension for podcasts.

  `extend_rss`(entry)

    Add additional fields to an RSS item.

    Parameters: | feed – The RSS item XML element to use.

  `itunes_author`(itunes_author=None)

    Get or set the itunes:author of the podcast episode. The content of this tag is shown in the Artist column in iTunes. If the tag is not present, iTunes uses the contents of the <author> tag. If <itunes:author> is not present at the feed level, iTunes will use the contents of <managingEditor>.

    Parameters: | itunes_author – The author of the podcast.
    Returns: | The author of the podcast.

  `itunes_block`(itunes_block=None)

    Get or set the ITunes block attribute. Use this to prevent episodes from appearing in the iTunes podcast directory.

    Parameters: | itunes_block – Block podcast episodes.
    Returns: | If the podcast episode is blocked.

  `itunes_duration`(itunes_duration=None)

    Get or set the duration of the podcast episode. The content of this tag is shown in the Time column in iTunes.

    The tag can be formatted HH:MM:SS, H:MM:SS, MM:SS, or M:SS (H = hours, M = minutes, S = seconds). If an integer is provided (no colon present), the value is assumed to be in seconds. If one colon is present, the number to the left is assumed to be minutes, and the number to the right is assumed to be seconds. If more than two colons are present, the numbers farthest to the right are ignored.

    Parameters: | itunes_duration – Duration of the podcast episode.
    Returns: | Duration of the podcast episode.

  `itunes_explicit`(itunes_explicit=None)

    Get or the the itunes:explicit value of the podcast episode. This tag should be used to indicate whether your podcast episode contains explicit material. The three values for this tag are “yes”, “no”, and “clean”.

    If you populate this tag with “yes”, an “explicit” parental advisory graphic will appear next to your podcast artwork on the iTunes Store and in the Name column in iTunes. If the value is “clean”, the parental advisory type is considered Clean, meaning that no explicit language or adult content is included anywhere in the episodes, and a “clean” graphic will appear. If the explicit tag is present and has any other value (e.g., “no”), you see no indicator — blank is the default advisory type.

    Parameters: | itunes_explicit – If the podcast episode contains explicit material.
    Returns: | If the podcast episode contains explicit material.

  `itunes_image`(itunes_image=None)

    Get or set the image for the podcast episode. This tag specifies the artwork for your podcast. Put the URL to the image in the href attribute. iTunes prefers square .jpg images that are at least 1400x1400 pixels, which is different from what is specified for the standard RSS image tag. In order for a podcast to be eligible for an iTunes Store feature, the accompanying image must be at least 1400x1400 pixels.

    iTunes supports images in JPEG and PNG formats with an RGB color space (CMYK is not supported). The URL must end in ”.jpg” or ”.png”. If the <itunes:image> tag is not present, iTunes will use the contents of the RSS image tag.

    If you change your podcast’s image, also change the file’s name. iTunes may not change the image if it checks your feed and the image URL is the same. The server hosting your cover art image must allow HTTP head requests for iTS to be able to automatically update your cover art.

    Parameters: | itunes_image – Image of the podcast.
    Returns: | Image of the podcast.

  `itunes_is_closed_captioned`(itunes_is_closed_captioned=None)

    Get or set the is_closed_captioned value of the podcast episode. This tag should be used if your podcast includes a video episode with embedded closed captioning support. The two values for this tag are “yes” and “no”.

    Parameters: | is_closed_captioned – If the episode has closed captioning support.
    Returns: | If the episode has closed captioning support.

  `itunes_order`(itunes_order=None)

    Get or set the itunes:order value of the podcast episode. This tag can be used to override the default ordering of episodes on the store.

    This tag is used at an <item> level by populating with the number value in which you would like the episode to appear on the store. For example, if you would like an <item> to appear as the first episode in the podcast, you would populate the <itunes:order> tag with “1”. If conflicting order values are present in multiple episodes, the store will use default ordering (pubDate).

    To remove the order from the episode set the order to a value below zero.

    Parameters: | itunes_order – The order of the episode.
    Returns: | The order of the episode.

  `itunes_subtitle`(itunes_subtitle=None)

    Get or set the itunes:subtitle value for the podcast episode. The contents of this tag are shown in the Description column in iTunes. The subtitle displays best if it is only a few words long.

    Parameters: | itunes_subtitle – Subtitle of the podcast episode.
    Returns: | Subtitle of the podcast episode.

  `itunes_summary`(itunes_summary=None)

    Get or set the itunes:summary value for the podcast episode. The contents of this tag are shown in a separate window that appears when the “circled i” in the Description column is clicked. It also appears on the iTunes page for your podcast. This field can be up to 4000 characters. If <itunes:summary> is not included, the contents of the <description> tag are used.

    Parameters: | itunes_summary – Summary of the podcast episode.
    Returns: | Summary of the podcast episode.